#!/usr/bin/env python
# *********************************************************************
# * Copyright (C) 2012 Luca Baldini (luca.baldini@pi.infn.it)         *
# *                                                                   *
# * For the license terms see the file LICENCE, distributed           *
# * along with this software.                                         *
# *********************************************************************
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.


from distutils.core import setup
import glob

from plasduino.__tag__ import TAG


setup(name = 'plasduino',
      description = 'Hardware/software framework for lab data acquisition',
      version = TAG,
      author = 'Luca Baldini',
      author_email = 'luca.baldini@pi.infn.it',
      license = 'GNU General Public License v3 or later',
      url = 'https://bitbucket.org/lbaldini/plasduino/overview',
      requires = ['pyserial', 'PyQt4'],
      packages = ['plasduino', 'plasduino.arduino', 'plasduino.artwork',
                  'plasduino.calibration', 'plasduino.daq', 'plasduino.data',
                  'plasduino.doc', 'plasduino.gui', 'plasduino.modulemanager',
                  'plasduino.sensors', 'plasduino.shields', 'plasduino.test'],
      package_dir = {'plasduino': '.'},
      package_data = {'plasduino': ['LICENSE', 'README', 'runId.cfg.sample',
                                    'plasduino.cfg.sample', 'Makefile',
                                    'debian/control', 'debian/changelog',
                                    'debian/compat', 'debian/copyright',
                                    'debian/rules', 'debian/postinst',
                                    'debian/plasduino.manpages'],
                      'plasduino.arduino': ['*.h', '*.cpp', 'boards.txt',
                                            'SConstruct', '*/*.ino', '*/*.hex'],
                      'plasduino.artwork': ['skins/*/*.svg', 'skins/*/*.png'],
                      'plasduino.calibration': [],
                      'plasduino.daq': [],
                      'plasduino.data': ['*.dat', '*.txt', '*.png', '*.avi'],
                      'plasduino.doc': ['*.1', 'release.notes'],
                      'plasduino.gui': [],
                      'plasduino.modulemanager': [],
                      'plasduino.sensors' : ['*.dat'],
                      'plasduino.shields' : ['lab1/*', 'parts/*'],
                      'plasduino.test': []
                      },
      scripts = glob.glob('modules/*.py')+['modules/plasduino'],
      classifiers = [
        'Development Status :: 3 - Alpha',
        'Environment :: Console',
        'Environment :: X11 Applications',
        'Intended Audience :: Education',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: GNU General Public License v3 or later'
        '(GPLv3+)',
        'Operating System :: POSIX :: Linux',
        'Programming Language :: Python',
        'Topic :: Education',
        'Topic :: Scientific/Engineering :: Physics',
        ]
      )
